@@ -5,6 +5,36 @@ partition_t.plot<-function(data, Ctime = Inf, arm.name = c(1,2), priority = c(1,
   #### match the argument
   trt_group = match.arg(trt_group)
 
+  #### Remove missing values
+  colname.ds = colnames(data)
+
+  if(sum(is.na(data))>0){
+    if(max(c("arm","trt","treat","treatment")%in%colname.ds)==TRUE){
+      arm0 = data[,which(colname.ds%in%c("arm","trt","treat","treatment"))]
+    }else{
+      stop("The treatment variable is not found. Please rename the treatment variable to arm, trt, treat or treatment.")
+    }
+    ind.missing.trt = which(apply(data[arm0==arm.name[1],], 1, func<-function(x) sum(is.na(x))>0))
+    ind.missing.con = which(apply(data[arm0==arm.name[2],], 1, func<-function(x) sum(is.na(x))>0))
+    if(is.null(Z_t_trt) == FALSE){
+      if("id"%in%colname.ds==TRUE){
+        if(length(ind.missing.trt) > 0){
+          id_trt0 = data[arm0==arm.name[1],which(colname.ds%in%c("id"))]
+          Z_t_trt = Z_t_trt[Z_t_trt$id %in% id_trt0[-ind.missing.trt],]
+        }
+        if(length(ind.missing.con) > 0){
+          id_con0 = data[arm0==arm.name[2],which(colname.ds%in%c("id"))]
+          Z_t_con = Z_t_con[Z_t_con$id %in% id_con0[-ind.missing.con],]
+        }
+      }else{
+        stop("The id variable is not found in Z_t_trt and Z_t_con.")
+      }
+    }
+    data = na.omit(data)
+    cat(length(ind.missing.trt)," and ",length(ind.missing.con),
+        " objects with missing values are removed in the treatment and control group, respectively.","\n")
+  }
+
   #### obtain the number of endpoints and total number of individuals
   n_ep = length(priority)
   n_total = dim(data)[1]
@@ -19,7 +49,6 @@ partition_t.plot<-function(data, Ctime = Inf, arm.name = c(1,2), priority = c(1,
   #############################################################################################
   #### Reorganize the data
   #############################################################################################
-  colname.ds = colnames(data)
   if(max(c("arm","trt","treat","treatment")%in%colname.ds)==TRUE){
     arm = data[,which(colname.ds%in%c("arm","trt","treat","treatment"))]
   }else{
